@@ -1,12 +1,13 @@
 # argumentor - A simple, copylefted, lightweight library to work with command-line arguments in Python
-# Copyright (C) 2021 Twann <twann@ctemplar.com>
+# Licensed under LGPLv3
+# Copyright (C) 2021-2022 Twann <tw4nn@disroot.org>
 
 import sys
 import re
 from .exceptions import ExecNameError, OperationExistsError, OptionExistsError, ArgumentValueError, GroupExistsError, \
     GroupNotExistsError, InvalidOptionError, InvalidOperationError
 
-__version__ = '0.0.5'
+__version__ = '0.0.6'
 
 
 class Arguments:
@@ -21,7 +22,7 @@ class Arguments:
         :param exec_name: Optional. The name of the executable running. If not set, sys.argv[0] will be used
         :param help_page: Optional. Specify a custom help page as self.help_page. If None, argumentor will generate one
         :param one_operation_required: Defaults to True. If no operation is specified, the script will return an error
-        :param allow_short_args_together: Defaults to True. Allow short arguments to be combined together
+        :param allow_short_args_together: Defaults to True. Allow short arguments to be combined
         :param show_operation_groups_on_help_page: Defaults to True. Group operations by group on generated help page
         :param show_option_groups_on_help_page: Defaults to True. Group options by group on generated help page
         (ex. '-vz' instead of '-v -z')
@@ -187,7 +188,9 @@ class Arguments:
         :param short_operation: Optional. The short version of the operation (ex. '-h')
         :param required: Defaults to False. Choose if the operation is required or not
         :param group: Optional. Specify an operation group
-        :param default_value. Specify the default value to use if the argument is not passed. Defaults to None or False for bool.
+        :param default_value. Specify the default value to use if the argument is not passed. Defaults to None
+        (or False for bool).
+
         :return:
         """
         if operation in self.operations.keys():
@@ -202,17 +205,21 @@ class Arguments:
             raise ArgumentValueError(f'value type "{value_type}" is not supported')
         elif group is not None and group not in self.operation_groups:
             raise GroupNotExistsError(f'operation group "{group}" does not exist')
-        elif short_operation is not None and len(short_operation) > 1 and not re.match(r'-[A-z0-9]', short_operation):
-            raise InvalidOperationError(f'short operation can only be one-character long when no dash, not "{short_operation}"')
+        elif short_operation is not None and len(short_operation) > 1 and not re.match(r'-[A-z\d]', short_operation):
+            raise InvalidOperationError(
+                f'short operation can only be one-character long when no dash, not "{short_operation}"')
         elif short_operation is not None and len(short_operation) > 2:
-            raise InvalidOperationError(f'short operation can contain a dash and a character maximum, not "{short_operation}"')
+            raise InvalidOperationError(
+                f'short operation can contain a dash and a character maximum, not "{short_operation}"')
         elif short_operation == operation:
             raise InvalidOperationError('short operation is equal to long operation')
         else:
             if default_value is None and value_type == bool:
                 default_value = False
             elif default_value is not None and type(default_value) != value_type:
-                raise ArgumentValueError(f'default value for operation {operation} is from type "{type(default_value)}" instead of "{value_type}"')
+                raise ArgumentValueError(
+                    f'default value for operation {operation} is from '
+                    f'type "{type(default_value)}" instead of "{value_type}"')
             self.operations[operation] = {
                 'value_type': value_type,
                 'description': description,
@@ -232,7 +239,7 @@ class Arguments:
         """
         Create an operation group
         :param group_name: The name of the group
-        :param name: Optional. Specify a different name to show on the help page. This can be useful for multi-language support
+        :param name: Optional. Specify a different name to show on the help page.
         :return:
         """
 
@@ -259,7 +266,9 @@ class Arguments:
         :param required_by_groups: Optional. Every operation in the specified groups will fail without this option
         :param group: Optional. Specify an option group
         :param inherit_from_group: Defaults to True. Inherit requirements and availability from group.
-        :param default_value. Specify the default value to use if the argument is not passed. Defaults to None or False for bool.
+        :param default_value. Specify the default value to use if the argument is not passed. Defaults to None
+        (or False for bool).
+
         :return:
         """
         if option in self.options.keys():
@@ -274,17 +283,20 @@ class Arguments:
             raise ArgumentValueError(f'value type "{value_type}" is not supported')
         elif group is not None and group not in self.option_groups.keys():
             raise GroupNotExistsError(f'option group "{group}" does not exist')
-        elif not re.match(r'--[A-z0-9\-]*', option):
+        elif not re.match(r'--[A-z\d\-]*', option):
             raise InvalidOptionError(f'option should start with two dashes: "--", not "{short_option}"')
         elif short_option is not None and len(short_option) != 2:
             raise InvalidOptionError(f'short option must be two-characters long, not "{short_option}"')
-        elif short_option is not None and not re.match(r'-[A-z0-9]', short_option):
-            raise InvalidOptionError(f'short option must start with a dash and finish with a character, not "{short_option}"')
+        elif short_option is not None and not re.match(r'-[A-z\d]', short_option):
+            raise InvalidOptionError(
+                f'short option must start with a dash and finish with a character, not "{short_option}"')
         else:
             if default_value is None and value_type == bool:
                 default_value = False
             elif default_value is not None and type(default_value) != value_type:
-                raise ArgumentValueError(f'default value for operation {option} is from type "{type(default_value)}" instead of "{value_type}"')
+                raise ArgumentValueError(
+                    f'default value for operation {option} is '
+                    f'from type "{type(default_value)}" instead of "{value_type}"')
             if group is not None and inherit_from_group:
                 self.options[option] = {
                     'value_type': value_type,
@@ -332,7 +344,7 @@ class Arguments:
         """
         Create an option group
         :param group_name: The name of the groups
-        :param name: Optional. Specify a different name to show on the help page. This can be useful for multi-language support
+        :param name: Optional. Specify a different name to show on the help page.
         :param available_with_operations: Optional. Options will only be available with operation in the list
         :param required_by_operations: Optional. Every operation in the list will fail without these options
         :param available_with_groups: Optional. Options will only be available with operation in the specified groups
@@ -358,7 +370,25 @@ class Arguments:
 
             self.active_operation = operation_title
 
-            if self.operations[operation_title]['value_type'] == bool:
+            if len(real_argument.split("=")) == 2:
+                if self.operations[operation_title]['value_type'] == int:
+                    try:
+                        self.output_operations[operation_title] = int(real_argument.split("=")[1])
+                        self.isolate_unmatched = False
+                    except ValueError:
+                        print(f'Error: operation "{real_operation}" requires an integer')
+                        raise SystemExit(1)
+                elif self.operations[operation_title]['value_type'] == str:
+                    if real_argument.split("=")[1]:
+                        self.output_operations[operation_title] = str(real_argument.split("=")[1])
+                        self.isolate_unmatched = False
+                    else:
+                        print(f'Error: operation "{real_operation}" requires at least one argument')
+                        raise SystemExit(1)
+                else:
+                    print(f'Error: operation "{real_operation}" does not support the "=" operator')
+                    raise SystemExit(1)
+            elif self.operations[operation_title]['value_type'] == bool:
                 self.output_operations[operation_title] = True
             elif len(self.arguments) - self.arguments.index(real_argument) > 1:
                 if self.operations[operation_title]['value_type'] == int:
@@ -388,20 +418,37 @@ class Arguments:
             raise SystemExit(1)
 
         elif self.active_operation is not None and self.options[option_title]['available_with_groups'] is not None \
-                and self.operations[self.active_operation]['group'] not in self.options[option_title]['available_with_groups']:
+                and self.operations[self.active_operation]['group'] not in \
+                self.options[option_title]['available_with_groups']:
             print(f'Error: option "{real_option}" is not available with operation "{self.active_operation}"')
             raise SystemExit(1)
 
         else:
 
-            if self.options[option_title]['value_type'] == bool:
+            if len(real_argument.split("=")) == 2:
+                if self.options[option_title]['value_type'] == int:
+                    try:
+                        self.output_options[option_title] = int(real_argument.split("=")[1])
+                    except ValueError:
+                        print(f'Error: option "{real_option}" requires an integer')
+                        raise SystemExit(1)
+                elif self.options[option_title]['value_type'] == str:
+                    if real_argument.split("=")[1]:
+                        self.output_options[option_title] = str(real_argument.split("=")[1])
+                    else:
+                        print(f'Error: option "{real_option}" requires at least one argument')
+                        raise SystemExit(1)
+                else:
+                    print(f'Error: option "{real_option}" does not support the "=" operator')
+                    raise SystemExit(1)
+            elif self.options[option_title]['value_type'] == bool:
                 self.output_options[option_title] = True
             elif len(self.arguments) - self.arguments.index(real_argument) > 1:
                 if self.options[option_title]['value_type'] == int:
                     try:
                         self.output_options[option_title] = int(self.arguments[self.arguments.index(real_argument) + 1])
                     except ValueError:
-                        print(f'Error: operation "{real_option}" requires an integer')
+                        print(f'Error: option "{real_option}" requires an integer')
                         raise SystemExit(1)
                     else:
                         self.arguments.pop(self.arguments.index(real_argument) + 1)
@@ -411,7 +458,7 @@ class Arguments:
                 elif self.options[option_title]['value_type'] == list:
                     self.output_options[option_title] = []
                     for value in self.arguments[self.arguments.index(real_argument) + 1:]:
-                        if re.match(r'-[A-z0-9_.\-]*', value):
+                        if re.match(r'-[A-z\d_.\-]*', value):
                             break
                         else:
                             self.output_options[option_title].append(value)
@@ -466,6 +513,22 @@ class Arguments:
                     real_argument=argument
                 )
 
+            elif len(argument.split("=")) == 2 and argument.split("=")[0] in self.operations.keys():
+
+                self.__match_operation(
+                    operation_title=argument.split("=")[0],
+                    real_operation=argument.split("=")[0],
+                    real_argument=argument
+                )
+
+            elif len(argument.split("=")) == 2 and argument.split("=")[0] in self.options.keys():
+
+                self.__match_option(
+                    option_title=argument.split("=")[0],
+                    real_option=argument.split("=")[0],
+                    real_argument=argument
+                )
+
             elif self.allow_short_args_together and len(argument) > 1 and \
                     (argument[0:1] in self.short_operations.keys() or argument[0:2] in self.short_operations.keys()):
 
@@ -514,18 +577,23 @@ class Arguments:
                         print(f'Error: invalid argument "{character}" in "{argument}"')
                         raise SystemExit(1)
 
-            elif self.isolate_unmatched and self.active_operation is not None and not re.match(r'-[A-z0-9_.\-]*', argument) \
+            elif self.isolate_unmatched and self.active_operation is not None and \
+                    not re.match(r'-[A-z\d_.\-]*', argument) \
                     and self.operations[self.active_operation]['value_type'] == list:
 
                 self.output_operations[self.active_operation].append(argument)
 
-            elif self.isolate_unmatched and self.active_operation is not None and not re.match(r'-[A-z0-9_.\-]*', argument) \
-                    and self.operations[self.active_operation]['value_type'] == str and self.output_operations[self.active_operation] is None:
+            elif self.isolate_unmatched and self.active_operation is not None and \
+                    not re.match(r'-[A-z\d_.\-]*', argument) \
+                    and self.operations[self.active_operation]['value_type'] == str and \
+                    self.output_operations[self.active_operation] is None:
 
                 self.output_operations[self.active_operation] = argument
 
-            elif self.isolate_unmatched and self.active_operation is not None and not re.match(r'-[A-z0-9_.\-]*', argument) \
-                    and self.operations[self.active_operation]['value_type'] == int and self.output_operations[self.active_operation] is None:
+            elif self.isolate_unmatched and self.active_operation is not None and \
+                    not re.match(r'-[A-z\d_.\-]*', argument) \
+                    and self.operations[self.active_operation]['value_type'] == int and \
+                    self.output_operations[self.active_operation] is None:
 
                 try:
                     self.output_operations[self.active_operation] = int(argument)
@@ -538,12 +606,14 @@ class Arguments:
                 print(f'Error: invalid argument "{argument}"')
                 raise SystemExit(1)
 
-        # Check if all active operations that require a list, a str or a int have at least one value
+        # Check if all active operations that require a list, a str or an int have at least one value
         for active_operation in self.output_operations.keys():
-            if self.operations[active_operation]['value_type'] == list and self.output_operations[active_operation] == []:
+            if self.operations[active_operation]['value_type'] == list and \
+                    self.output_operations[active_operation] == []:
                 print(f'Error: operation "{active_operation}" requires at least one argument')
                 raise SystemExit(1)
-            elif self.operations[active_operation]['value_type'] in (str, int) and self.output_operations[active_operation] is None:
+            elif self.operations[active_operation]['value_type'] in (str, int) and \
+                    self.output_operations[active_operation] is None:
                 print(f'Error: operation "{active_operation}" requires at least one argument')
                 raise SystemExit(1)
 
@@ -566,7 +636,8 @@ class Arguments:
             if self.options[option]['required_by_groups'] is not None and option not in self.output_options:
                 for required_group in self.options[option]['required_by_groups']:
                     for operation in self.operations:
-                        if self.operations[operation]['group'] == required_group:
+                        if self.operations[operation]['group'] == required_group and \
+                                operation in self.output_operations:
                             print(f'Error: operation "{operation}" requires the option "{option}"')
                             raise SystemExit(1)
 
